==> haskell-half-0.3.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 half
version:              0.3.3
visibility:           public
id:                   half-0.3.3-7bHujTHlubyCizCOczF7LC
key:                  half-0.3.3-7bHujTHlubyCizCOczF7LC
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  f93bd16f1771b30e769db4f141695d3d
exposed:              True
exposed-modules:      Numeric.Half Numeric.Half.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/half-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-half
hs-libraries:         HShalf-0.3.3-7bHujTHlubyCizCOczF7LC
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-half-0.3.3-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-half.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 half
version:              0.3.3
visibility:           public
id:                   half-0.3.3-65CPxfT66kL7KHVcTfsvaJ
key:                  half-0.3.3-65CPxfT66kL7KHVcTfsvaJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/half
synopsis:             Half-precision floating-point
description:          Half-precision floating-point.
category:             Numeric
abi:                  ba35c38933c69b240c3f06f4ada2c1a2
exposed:              True
exposed-modules:      Numeric.Half Numeric.Half.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/half-0.3.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/half-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-half
hs-libraries:         HShalf-0.3.3-65CPxfT66kL7KHVcTfsvaJ
depends:
    base-4.17.2.1 binary-0.8.9.1 deepseq-1.4.8.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-half/html/half.haddock
haddock-html:         /usr/share/doc/haskell-half/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
